Name:           httpcomponents-core
Summary:        Set of low level Java HTTP transport components for HTTP services
Version:        4.4.12
Release:        %mkrel 1
Group:          Development/Java
License:        ASL 2.0
URL:            http://hc.apache.org/
Source0:        http://www.apache.org/dist/httpcomponents/httpcore/source/httpcomponents-core-%{version}-src.tar.gz
Patch0:         0001-Port-to-mockito-2.patch

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.httpcomponents:httpcomponents-parent:pom:)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.mockito:mockito-core)

%description
HttpCore is a set of low level HTTP transport components that can be
used to build custom client and server side HTTP services with a
minimal footprint. HttpCore supports two I/O models: blocking I/O
model based on the classic Java I/O and non-blocking, event driven I/O
model based on Java NIO.

The blocking I/O model may be more appropriate for data intensive, low
latency scenarios, whereas the non-blocking model may be more
appropriate for high latency scenarios where raw data throughput is
less important than the ability to handle thousands of simultaneous
HTTP connections in a resource efficient manner.

%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
%{summary}.


%prep
%setup -q
%patch0 -p1

# Random test failures on ARM -- 100 ms sleep is not eneough on this
# very performant arch, lets make it 2 s
sed -i '/Thread.sleep/s/100/2000/' httpcore-nio/src/test/java/org/apache/http/nio/integration/TestHttpAsyncHandlers.java

%pom_remove_plugin :maven-checkstyle-plugin
%pom_remove_plugin :apache-rat-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :maven-javadoc-plugin

# we don't need these artifacts right now
%pom_disable_module httpcore-osgi
%pom_disable_module httpcore-ab

# OSGify modules
for module in httpcore httpcore-nio; do
    %pom_xpath_remove "pom:project/pom:packaging" $module
    %pom_xpath_inject "pom:project" "<packaging>bundle</packaging>" $module
    %pom_remove_plugin :maven-jar-plugin $module
    %pom_xpath_inject "pom:build/pom:plugins" "
        <plugin>
          <groupId>org.apache.felix</groupId>
          <artifactId>maven-bundle-plugin</artifactId>
          <extensions>true</extensions>
          <configuration>
            <instructions>
              <Export-Package>*</Export-Package>
              <Private-Package></Private-Package>
              <Automatic-Module-Name>org.apache.httpcomponents.$module</Automatic-Module-Name>
              <_nouses>true</_nouses>
            </instructions>
          </configuration>
        </plugin>" $module
done

# install JARs to httpcomponents/ for compatibility reasons
# several other packages expect to find the JARs there
%mvn_file ":{*}" httpcomponents/@1

%build
%mvn_build -f

%install
%mvn_install

%files -f .mfiles
%doc LICENSE.txt NOTICE.txt README.txt RELEASE_NOTES.txt

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt NOTICE.txt




%changelog
* Mon Aug 24 2020 neoclust <neoclust> 4.4.12-1.mga8
+ Revision: 1618570
- New version 4.4.12

* Sat Feb 15 2020 umeabot <umeabot> 4.4.10-3.mga8
+ Revision: 1528465
- Mageia 8 Mass Rebuild

* Wed Aug 21 2019 daviddavid <daviddavid> 4.4.10-2.mga8
+ Revision: 1430784
- Add patch to allow building with mockito 2

* Mon Dec 10 2018 daviddavid <daviddavid> 4.4.10-1.mga7
+ Revision: 1339757
- new version: 4.4.10 (sync with fc29)

* Tue Sep 18 2018 umeabot <umeabot> 4.4.5-3.mga7
+ Revision: 1261833
- Mageia 7 Mass Rebuild

* Sun May 14 2017 neoclust <neoclust> 4.4.5-2.mga6
+ Revision: 1101340
- New version 4.4.5

* Wed Mar 02 2016 neoclust <neoclust> 4.4.4-3.mga6
+ Revision: 981798
- Second rebuild of the java stack

* Fri Feb 26 2016 neoclust <neoclust> 4.4.4-2.mga6
+ Revision: 979469
- First rebuild of the java stack
- sync package httpcomponents-core with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Thu Dec 25 2014 pterjan <pterjan> 4.3.2-5.mga5
+ Revision: 805630
- Clean rebuild
- Restore
+ sander85 <sander85>
- Depends on broken java stack

* Wed Oct 15 2014 umeabot <umeabot> 4.3.2-3.mga5
+ Revision: 740167
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Jun 29 2014 dmorgan <dmorgan> 4.3.2-1.mga5
+ Revision: 641198
- New version

* Sat Dec 21 2013 dmorgan <dmorgan> 4.3-1.mga4
+ Revision: 559551
- New version

* Mon Oct 21 2013 umeabot <umeabot> 4.2.4-2.mga4
+ Revision: 537591
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 dmorgan <dmorgan> 4.2.4-1.mga4
+ Revision: 487370
- New version

* Sun Sep 15 2013 dmorgan <dmorgan> 4.2.3-2.mga4
+ Revision: 479814
- Add missing BR: maven-local

* Mon Jul 08 2013 dmorgan <dmorgan> 4.2.3-1.mga4
+ Revision: 451336
- Update to upstream version 4.2.3

* Sat Jan 12 2013 umeabot <umeabot> 4.2.2-2.mga3
+ Revision: 353355
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 03 2012 dmorgan <dmorgan> 4.2.2-1.mga3
+ Revision: 325729
- New version

* Wed Sep 12 2012 dmorgan <dmorgan> 4.2.1-1.mga3
+ Revision: 292895
- New version

* Mon Jul 16 2012 dmorgan <dmorgan> 4.1.4-1.mga3
+ Revision: 271251
- New version 4.1.4

* Sat Dec 10 2011 dmorgan <dmorgan> 4.1.3-1.mga2
+ Revision: 179885
- New version 4.1.3

* Fri Dec 09 2011 dmorgan <dmorgan> 4.1.2-1.mga2
+ Revision: 179526
- Update to latest upstream (4.1.2)
- Fix forgotten add_to_maven_depmap
- Update to latest upstream (4.1.1)
    - Use new maven macros
    - Tweaks according to new guidelines
    - Enable tests again

* Thu Apr 28 2011 dmorgan <dmorgan> 4.1-7.mga1
+ Revision: 92453
- Rebuild after bootstrapping
- imported package httpcomponents-core


* Tue Mar 15 2011 Severin Gehwolf <sgehwolf@redhat.com> 4.1-6
- Explicitly set PrivatePackage to the empty set, so as to
  export all packages.

* Fri Mar 11 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-5
- Bump release to fix my mistake with the release.

* Thu Mar 10 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-3
- Export all packages.

* Fri Feb 18 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-2
- Don't use basename it's part of coreutils. 

* Fri Feb 18 2011 Alexander Kurtakov <akurtako@redhat.com> 4.1-4
- Install into %%{_javadir}/httpcomponents. We will use it for client libs too.
- Proper osgi info.

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Dec 22 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 4.1-2
- Added license to javadoc subpackage

* Fri Dec 17 2010 Stanislav Ochotnicky <sochotnicky@redhat.com> - 4.1-1
- Initial package
